@@ -7,6 +7,7 @@ from dddd_utils.mysql import StoreMysqlPool
 from dddd_utils.ffdm import get_ffdm_api
 from dddd_utils.logger import get_logger
 from dddd_utils.mail import UtilMail
+from dddd_utils.apollo import ApolloClient
 
 __all__ = [
     'BaseSpider',  # 爬虫基类
@@ -16,5 +17,6 @@ __all__ = [
     'StoreMysqlPool',  # mysql
     'get_ffdm_api',  # 验证码
     'get_logger',  # logger
-    'UtilMail'  # 邮件工具类
+    'UtilMail',  # 邮件工具类
+    'ApolloClient'  # apollo 配置中心 python客户端
 ]
